@@ -39,7 +39,10 @@ KNOWN_EXTRA_OUTPUT_KEYS = [
     'athena.GetQueryResults.ResultSet',
     'cloudfront.ListCloudFrontOriginAccessIdentities.CloudFrontOriginAccessIdentityList',
     'cloudfront.ListDistributions.DistributionList',
+    'cloudfront.ListDistributionsByConnectionMode.DistributionList',
     'cloudfront.ListInvalidations.InvalidationList',
+    'cloudfront.ListInvalidationsForDistributionTenant.InvalidationList',
+    'cloudfront.ListOriginAccessControls.OriginAccessControlList',
     'cloudfront.ListPublicKeys.PublicKeyList',
     'cloudfront.ListStreamingDistributions.StreamingDistributionList',
     'cloudfront.ListKeyValueStores.KeyValueStoreList',
